@@ -534,8 +534,8 @@ time_t filetime;
 	timestr[12] = '\0';
     else {
 	timestr[6] = '\0';
-	strcat (timestr, " 19");
-	strcat (timestr, itoa (filetm.tm_year));
+	strcat (timestr, " ");
+	strcat (timestr, itoa (filetm.tm_year + 1900));
     }
 
     return timestr;
