@@ -369,6 +369,8 @@ itcl_class dsk_Editor {
 	if {[hsearch_history get] == {}} {
 	    # Linux HOWTO:
 	    hsearch_history add {^  [1-9]\.}
+	    # UNIX man pages:
+	    hsearch_history add {^[A-Z][-A-Z1-90 ]*$}
 	    # Tcl/itcl code:
 	    hsearch_history add {^[ ]*proc|^[ ]*method|^[ ]*class|^[ ]*itcl_class|^[ ]*constructor|^[ ]*destructor}
 	    # C/C++ functions:
@@ -376,7 +378,9 @@ itcl_class dsk_Editor {
 	}
 
 	eval config $args
-	cb_deiconify $this
+	if {!$files_set} {
+	    cb_deiconify $this
+	}
 	update
     }
 
@@ -398,6 +402,10 @@ itcl_class dsk_Editor {
     method config {config} {
     }
 
+    method cget {var} {
+	return [set [string trimleft $var -]]
+    }
+
     method load {} {
 	global tkdesk
 
@@ -553,9 +561,11 @@ itcl_class dsk_Editor {
 	    if [file exists $old_auto_fname] {
 		catch {exec rm $old_auto_fname}
 	    }
-	    
-	    if [set [set this](send_netscape)] {
-		dsk_netscape file [cb_tilde $file expand]
+
+	    catch {
+		if [set [set this](send_netscape)] {
+		    dsk_netscape file [cb_tilde $file expand]
+		}
 	    }
 	}
 	$this.ft.text config -state normal
@@ -596,10 +606,12 @@ itcl_class dsk_Editor {
 	set buffer($id,cursor) 1.0
 	set buffer($id,win) $this
 	set buffer($id,newfile) 1
-	if ![file writable [file dirname $file]] {
-	    set buffer($id,readonly) 1
-	} else {
+	if {[file writable [file dirname $file]] \
+		|| [string match "New *" $buffer($id,file)] \
+		|| [string match "* (Output)" $curfile]} {
 	    set buffer($id,readonly) 0
+	} else {
+	    set buffer($id,readonly) 1
 	}
 	set changed($id) 0
 	set undo_enabled($id) 0
@@ -620,102 +632,129 @@ itcl_class dsk_Editor {
 	}
 
 	set id ""
+	set linenum 0
 	if ![file exists $file] {
 	    if !$insert {
-		set id [$this buffer new $file]
+		set le [lindex $file 0]
+		if [regexp {^\+[1-90]+$} $le] {
+		    set linenum [string trimleft $le "+"]
+		    set file [lrange $file 1 [llength $file]]
+		} else {
+		    set id [$this buffer new $file]
+		    return $id
+		}
 	    } else {
 		cb_error "$file does not exist."
-	    }
-	} else {
-	    if [file isdirectory $file] {
-		dsk_errbell
-		cb_error "Please use TkDesk's file windows to edit directories! ;-)"
-		#catch "$this delete"
-		return -1
-		
-	    }
-
-	    # see if this file is already loaded
-	    #for {set id 1} {$id <= $bufcount} {incr id} {
-	    #	 if ![info exists buffer($id,file)] continue
-	    #	 if {$buffer($id,file) == $file} {
-	    #	     $buffer($id,win) buffer display $id
-	    #	     return
-	    #	 }
-	    #}
-	    
-	    if {[file size $file] > 500000} {
-		if {[cb_okcancel "You're about to load a very large file into the editor. This will probably take ages and require a ridiculous amount of memory. Continue anyway?"] == 1} {
-		    if !$insert {
-			catch "$this delete"
-		    }
-		    return -1
-		}
-	    }
-	    set ext [file extension $file]
-	    if {$ext == ".gz" || $ext == ".z"} {
-	        set err [catch  {set fd [open "|gzip -cd \"$file\""]}]
-	    } elseif {$ext == ".Z"} {
-	        set err [catch  {set fd [open "|zcat \"$file\""]}]
-	    } else {
-	        set err [catch {set fd [open $file]}]
-	    }
-	    if $err {
-		dsk_errbell
-		catch "cb_error \"Error: Couldn't open $file for reading!\""
-		if !$insert {
-		    catch "$this delete"
-		}
-		return -1
-	    }
-	    set err [dsk_catch {
-		dsk_busy
-		if !$insert {
-		    set id [incr bufcount]
-		    set buffer($id,file) $file
-		    set buffer($id,text) [read $fd]
-		    set buffer($id,vpos) 0
-		    set buffer($id,cursor) 1.0
-		    set buffer($id,win) $this
-		    set buffer($id,newfile) 0
-		    set changed($id) 0
-		    set undo_enabled($id) 0
-		    set undo_list($id) ""
-		    set undo_pointer($id) -1
-		    
-		    if ![file writable $file] {
-			#cb_alert "Opening file read-only."
-			set buffer($id,readonly) 1
-		    } else {
-			set buffer($id,readonly) 0
-		    }
-		} else {
-		    $this.ft.text insert insert [read $fd]
-		    cb_Text_change_callback $this.ft.text
-		}
-		close $fd
-		dsk_lazy
-	    }]
-	    if $err {
-		if !$insert {
-		    catch "$this delete"
-		}
-		return -1
-	    }
-	    if $insert {
 		return
 	    }
-	    $this buffer display $id
 	}
+	
+	if [file isdirectory $file] {
+	    dsk_errbell
+	    cb_error "Please use TkDesk's file windows to edit directories! ;-)"
+	    #catch "$this delete"
+	    return -1
+	    
+	}
+
+	# see if this file is already loaded
+	#for {set id 1} {$id <= $bufcount} {incr id} {
+	#	 if ![info exists buffer($id,file)] continue
+	#	 if {$buffer($id,file) == $file} {
+	#	     $buffer($id,win) buffer display $id
+	#	     return
+	#	 }
+	#}
+	    
+	if {[file size $file] > 500000} {
+	    if {[cb_okcancel "You're about to load a very large file into the editor. This will probably take ages and require a ridiculous amount of memory. Continue anyway?"] == 1} {
+		#if !$insert {
+		#	 catch "$this delete"
+		#}
+		return -1
+	    }
+	}
+	set ext [file extension $file]
+	if {$ext == ".gz" || $ext == ".z"} {
+	    set err [catch  {set fd [open "|gzip -cd \"$file\""]}]
+	} elseif {$ext == ".Z"} {
+	    set err [catch  {set fd [open "|zcat \"$file\""]}]
+	} else {
+	    set err [catch {set fd [open $file]}]
+	}
+	if $err {
+	    dsk_errbell
+	    catch "cb_error \"Error: Couldn't open $file for reading!\""
+	    #if !$insert {
+	    #    catch {$this delete}
+	    #}
+	    return -1
+	}
+	set err [dsk_catch {
+	    dsk_busy
+	    if !$insert {
+		set id [incr bufcount]
+		set buffer($id,file) $file
+		set buffer($id,text) [read $fd]
+		set buffer($id,vpos) 0
+		set buffer($id,cursor) 1.0
+		set buffer($id,win) $this
+		set buffer($id,newfile) 0
+		set changed($id) 0
+		set undo_enabled($id) 0
+		set undo_list($id) ""
+		set undo_pointer($id) -1
+		    
+		if ![file writable $file] {
+		    #cb_alert "Opening file read-only."
+		    set buffer($id,readonly) 1
+		} else {
+		    set buffer($id,readonly) 0
+		}
+	    } else {
+		$this.ft.text insert insert [read $fd]
+		cb_Text_change_callback $this.ft.text
+	    }
+	    close $fd
+	    dsk_lazy
+	}]
+	if $err {
+	    #if !$insert {
+	    #    catch "$this delete"
+	    #}
+	    return -1
+	}
+	if $insert {
+	    return 0
+	}
+	if {$linenum > 0} {
+	    set buffer($id,linenum) $linenum
+	}
+	$this buffer display $id
+
 	if {[string first $tkdesk(configdir) $file] == 0} {
+	    
 	    if ![winfo exists $this.fMenu.mbTkDesk] {
-		menubutton $this.fMenu.mbTkDesk -text "TkDesk" \
+		menubutton $this.fMenu.mbTkDesk -text "Configuration" \
 			-menu [set m $this.fMenu.mbTkDesk.m] \
 			-underline 0
 		pack propagate $this.fMenu 0
 		pack $this.fMenu.mbTkDesk -side left
 		
 		menu $m
+		$m add cascade -label "Load..." \
+			-menu $m.cfg
+		menu $m.cfg
+		foreach cf $tkdesk(configfiles) {
+		    set cfs [format "%-12s" $cf]
+		    $m.cfg add command \
+			    -label "$cfs 	($tkdesk(configxpl,$cf))" \
+			    -command "$this buffer create $tkdesk(configdir)/$cf"
+		}
+		$m add command -label "Find in Config..." \
+			-command "dsk_find_files -path $tkdesk(configdir) -name [list $tkdesk(configfiles)] -type file"
+		$m add separator
+		
 		$m add command -label "Save and Reload into TkDesk " \
 			-command "$this _tkdesk reload" \
 			-accelerator F5
@@ -772,10 +811,10 @@ itcl_class dsk_Editor {
 	global tkdesk
 	
 	set id $currentid
-	set curfile $buffer($currentid,file)
-	if {[string first $tkdesk(configdir) $curfile] < 0} {
+ 	set curfile [cb_tilde $buffer($currentid,file) expand]
+	if {[string first [cb_tilde $tkdesk(configdir) expand] $curfile] < 0} {
 	    dsk_errbell
-	    cb_error "This is not one of TkDesk's current configuration files!"
+	    cb_error "This buffer does currently not contain one of TkDesk's configuration files."
 	    return
 	}
 	
@@ -813,6 +852,12 @@ itcl_class dsk_Editor {
 	} else {
 	    $this.ft.text config -bg [cb_col $tkdesk(color,text)]
 	}
+	if [info exists buffer($id,linenum)] {
+	    $this.ft.text mark set insert $buffer($id,linenum).0
+	    $this.ft.text see insert
+	    unset buffer($id,linenum)
+	}
+	
 	if {[wm state $this] != "normal"} {
 	    cb_deiconify $this
 	} else {
@@ -847,6 +892,9 @@ itcl_class dsk_Editor {
 		_do_search $tkdesk(editor,findexp)
 	    }
 	}
+	if [winfo exists $this-hsearch] {
+	    _do_hsearch
+	}
     }
 
     method _buffer_delete {id {dontdel 0}} {
@@ -1211,11 +1259,14 @@ itcl_class dsk_Editor {
 
 	if {[string length "$cutbuffer"] > 0} {
 	    set t $this.ft.text
+	    $t yview -pickplace insert
 	    set bb [$t bbox [$t index insert]]
 	    $t insert insert $cutbuffer
 	    $t yview -pickplace insert
-	    cb_Text_change_callback $this.ft.text paste [list \
-		    [lindex $bb 0] [lindex $bb 1] $cutbuffer]
+	    if {$bb != ""} {
+		cb_Text_change_callback $this.ft.text paste [list \
+			[lindex $bb 0] [lindex $bb 1] $cutbuffer]
+	    }
 	    selection clear $this.ft.text
 	    catch "unset cb_Text(selstart)"
 	} else {
@@ -1265,14 +1316,14 @@ itcl_class dsk_Editor {
 	label $t.ls -text "Search for:" -anchor w
 	pack $t.ls -in $t.fslf -side left
 	checkbutton $t.cbRegexp -text "Regular Expr." -relief flat \
-		-variable [set this](regexp)
+		-variable [set this](regexp) -underline 0
 	pack $t.cbRegexp -in $t.fslf -side right
 	checkbutton $t.cbCase -text "Case Sensitive " -relief flat \
-		-variable [set this](case)
+		-variable [set this](case) -underline 0
 	pack $t.cbCase -in $t.fslf -side right
 	
 	frame $t.fsfe
-	entry $t.es -bd 2 -relief sunken -width 40
+	entry $t.es -bd 2 -relief sunken -width 40 -exportselection no
 	$t.es insert end $searchexp
 	pack $t.es -in $t.fsfe -fill x -expand yes \
 		-side left -ipady 2 -pady $tkdesk(pad)
@@ -1290,6 +1341,7 @@ itcl_class dsk_Editor {
 	
 	pack $t.fsfe -in $t.fsf -fill x -expand yes
 	
+	bind $t.es <Visibility> {%W selection range 0 end}
 	bind $t.es <1> \
 		"focus %W ;\
 		$t.bReplace config -relief flat ;\
@@ -1298,10 +1350,13 @@ itcl_class dsk_Editor {
 		"$this _do_search ;\
 		focus $t.er ;\
 		$t.bSearch config -relief flat ;\
-		$t.bReplace config -relief sunken"
-	bind $t.es <Escape> "destroy $t"
-	bind $t.es <Return> "$this _do_search"
-	bind $t.es <Control-s> "$this _do_search"
+		$t.bReplace config -relief sunken; break"
+	bind $t.es <Escape> "destroy $t; break"
+	bind $t.es <Return> "$this _do_search; break"
+	bind $t.es <Control-s> "$this _do_search; break"
+	#bind $t.es <KeyRelease> "+$this _do_search"
+	cb_addShortcutBinding $t.es $t.cbRegexp "r"
+	cb_addShortcutBinding $t.es $t.cbCase "c"
 
 	frame $t.fr -bd 1 -relief raised
 	pack $t.fr -fill both -expand yes
@@ -1312,7 +1367,7 @@ itcl_class dsk_Editor {
 	pack $t.lr -in $t.frf -anchor w
 
 	frame $t.frfr
-	entry $t.er -bd 2 -relief sunken -width 40
+	entry $t.er -bd 2 -relief sunken -width 40 -exportselection no
 	pack $t.er -in $t.frfr -side left \
 		-fill x -expand yes -ipady 2 -pady $tkdesk(pad)
 
@@ -1329,6 +1384,7 @@ itcl_class dsk_Editor {
 	
 	pack $t.frfr -in $t.frf -fill x -expand yes
 	
+	bind $t.er <Visibility> {%W selection range 0 end}
 	bind $t.er <1> \
 		"$this _do_search ;\
 		focus %W ;\
@@ -1340,6 +1396,8 @@ itcl_class dsk_Editor {
 		$t.bSearch config -relief sunken"
 	bind $t.er <Escape> "destroy $t; focus -force $this"
 	bind $t.er <Return> "$this _do_replace"
+	cb_addShortcutBinding $t.er $t.cbRegexp "r"
+	cb_addShortcutBinding $t.er $t.cbCase "c"
 
 	frame $t.fb -bd 1 -relief raised
 	pack $t.fb -fill x
@@ -1484,6 +1542,7 @@ itcl_class dsk_Editor {
 	    $tw tag add sel $mstart $mend
 	    $tw yview -pickplace $mstart
 	    $tw mark set insert $mend
+	    #$tw mark set insert $mstart
 	    set search_regexp $exp
 	} else {
 	    dsk_bell
@@ -1653,15 +1712,22 @@ itcl_class dsk_Editor {
 	bind $t <Any-Enter> "if \$tkdesk(focus_follows_mouse) \{focus $t.es\}"
 	
 	wm title $t "HyperSearch"
-	wm minsize $t 6 2
+	wm minsize $t 5 2
 	wm geometry $t 20x6
 	wm group $t $this
 	cb_deiconify $t
     }
 
     method _hsearch_callback {line_nr} {
-	$this.ft.text yview [expr [lindex $hsearch_lnr $line_nr] - 1]
-	$this.ft.text mark set insert $line_nr.0
+	if {[wm state $this] != "normal"} {
+	    cb_deiconify $this
+	} else {
+	    raise $this
+	}
+	#$this.ft.text yview [expr [lindex $hsearch_lnr $line_nr] - 1]
+	set lnr [lindex $hsearch_lnr $line_nr]
+	$this.ft.text mark set insert $lnr.0
+	$this.ft.text yview -pickplace insert
     }
 
     method _do_hsearch {} {
@@ -1713,22 +1779,23 @@ itcl_class dsk_Editor {
 	    set exp [$tw get [lindex $selr 0] [lindex $selr 1]]
 	    dsk_busy
 	    if ![set [set this](case)] {
-		set success [regexp -nocase -indices -- \
-			$exp [$tw get insert end] mrange]
+		set fi [$tw search -exact -nocase -- $exp insert end]
 	    } else {
-		set success [regexp -indices -- \
-			$exp [$tw get insert end] mrange]
+		set fi [$tw search -exact -- $exp insert end]
 	    }
 	    dsk_lazy
-	    if $success {
+	    if {$fi != ""} {
 		selection clear $tw
-		set mstart [lindex $mrange 0]
-		set mend [expr [lindex $mrange 1] + 1]
-		$tw tag add sel "insert + $mstart chars" "insert + $mend chars"
-		$tw yview -pickplace "insert + $mstart chars"
-		$tw mark set insert "insert + $mend chars"
+		$tw tag add sel $fi "$fi + [string length $exp] chars"
+		$tw yview -pickplace $fi
+		$tw mark set insert "$fi + [string length $exp] chars"
 	    } else {
-		dsk_bell
+		dsk_errbell
+		set restart ![cb_yesno "No more matches. Restart at top?"]
+		if $restart {
+		    $tw mark set insert 1.0
+		    findsel
+		}
 	    }
 	} else {
 	    dsk_bell
@@ -1812,11 +1879,12 @@ itcl_class dsk_Editor {
 	    }
 	} else {
 	    if $ask {
-		set val [cb_readString "Tab Width (Spaces):"]
-		if {$val == ""} {
-		    set tkdesk(editor,tab_width) 8
-		} else {
+		set val [cb_readString "Tab Width (Number of Spaces):"]
+		if [regexp {[1-90][1-90]*} $val] {
 		    set tkdesk(editor,tab_width) $val
+		} else {
+		    dsk_errbell
+		    set tkdesk(editor,tab_width) 8
 		}
 	    }
 	    bind $this.ft.text <Tab> "$this _tabstr; break"
@@ -1977,6 +2045,7 @@ itcl_class dsk_Editor {
     #
 
     public files "" {
+	set files_set 1
 	set dont_display 1
 	set id -1
 	foreach f $files {
@@ -1990,6 +2059,8 @@ itcl_class dsk_Editor {
 	set dont_display 0
 	if {$id != -1} {
 	    $this buffer display $id
+	} else {
+	    set files ""
 	}
 	dsk_status_ready
     }
@@ -2009,6 +2080,7 @@ itcl_class dsk_Editor {
     protected autosaveperiod 500
     protected undo_size 500
     protected dont_display 0
+    protected files_set 0
 
     common buffer
     common bufcount 0
