@@ -257,7 +257,7 @@ itcl_class dsk_FileListbox {
 	bind $this.dlb.text <Control-ButtonRelease-1> \
 	    "+if \$tkdesk(single_click) \{
 	     set tkdesk(file_lb,control) 1
-	     [winfo toplevel $this] _dblclick $this \[$this.dlb select get\]
+	     #[winfo toplevel $this] _dblclick $this \[$this.dlb select get\]
 	    \}
 	    $this _tag_icons
 	    $this _selstatus
@@ -512,7 +512,7 @@ itcl_class dsk_FileListbox {
 	if {$ptag != ""} {
 	    $this.dlb tag add path [lsearch [$this.dlb get] $pname]
 	}
-	dsk_lazy ;# "" 1
+	dsk_lazy
     }
 
     method clear {} {
@@ -1252,16 +1252,23 @@ itcl_class dsk_FileListbox {
 	global [set this]
 
 	if {$toplevel != ""} {
-	    $this.mb.menu delete 13	;# delete separator
-	    $this.mb.menu delete 14	;# delete " Open Window "
+	    if [$this.mb.menu cget -tearoff] {
+		set laste 15
+	    } else {
+		set laste 14
+	    }
+	    $this.mb.menu delete [expr $laste -1]  ;# delete separator
+	    $this.mb.menu delete $laste            ;# delete " Open Window "
 
-	    $this.mb.menu insert 12 checkbutton -label " Add Icons " \
-		-variable [set this](add_icons) \
-	        -command "$this config -add_icons \[set [set this](add_icons)\]"
+	    $this.mb.menu insert [expr $laste -2] checkbutton \
+		    -label " Add Icons " \
+	            -variable [set this](add_icons) \
+		    -command "$this config -add_icons \[set [set this](add_icons)\]"
 	    ::set [set this](add_icons) $add_icons
-	    $this.mb.menu insert 12 checkbutton -label " Folders On Top " \
-		-variable [set this](topfolders) \
-	      -command "$this config -topfolders \[set [set this](topfolders)\]"
+	    $this.mb.menu insert [expr $laste -2] checkbutton \
+		    -label " Folders On Top " \
+		    -variable [set this](topfolders) \
+		    -command "$this config -topfolders \[set [set this](topfolders)\]"
 	    ::set [set this](topfolders) $topfolders
 
 	    $this.mb.menu add separator
