@@ -116,9 +116,9 @@ proc dsk_open {viewer file} {
 	
 	set file [subst -nocommands -novariables [_make_fname_safe $file]]
 	set dname [file tail $file]
-	if {$dname == "."} {
+	if [string match $dname "."] {
 	    set file [file dirname $file]
-	} elseif {$dname == ".."} {
+	} elseif [string match $dname ".."] {
 	    set file [file dirname $file]
 	    set file [file dirname $file]
 	}
@@ -429,7 +429,9 @@ proc dsk_exec {args} {
     }
     set dsk_exec(bgcmd,$cnt) $cmd
     trace variable dsk_exec(bgvar,$cnt) w dsk_exec_trace
-    dsk_status "Launched:  $cmd"
+    regsub -all "\n" $cmd "; " cmd2
+    regsub -all "\[\t \]\[\t \]*" $cmd2 " " cmd2
+    dsk_status "Launched:  $cmd2"
     dsk_lazy
 
     lappend tkdesk(dsk_exec,pids) $pid
@@ -457,7 +459,9 @@ proc dsk_exec_trace {arr idx op} {
     unset dsk_exec(bgcmd,$num)
 
     dsk_sound dsk_exec_exit
-    dsk_status "Exit ($exit_code):  $cmd"
+    regsub -all "\n" $cmd "; " cmd2
+    regsub -all "\[\t \]\[\t \]*" $cmd2 " " cmd2
+    dsk_status "Exit ($exit_code):  $cmd2"
 
     if [info exists dsk_exec(bgdir,$num)] {
 	set tkdesk(inhibit_status) 1
@@ -611,9 +615,14 @@ proc dsk_ask_exec_ok {entry val} {
 	    [dsk_auto_execok [lindex $tmpcmd 0]]} {
 	set tmpcmd [_expand_pc $tmpcmd]
 	if $val {
-	    eval dsk_view $tmpcmd
+	    set err [catch {eval dsk_view $tmpcmd} errmsg]
 	} else {
-	    eval dsk_exec $tmpcmd
+	    set err [catch {eval dsk_exec $tmpcmd} errmsg]
+	}
+
+	if $err {
+	    dsk_errbell
+	    cb_error $errmsg
 	}
 
 	set cmd $tmpcmd
@@ -799,7 +808,12 @@ proc dsk_filesel_browse {entry val} {
 	}
     }
 
-    if [file isdirectory $entry] {
+    #set dir ""
+    #catch {set dir [file dirname $entry]}
+    set dir [_make_path_valid $entry]
+    set isdir 0
+    catch {set isdir [file isdirectory $entry]}
+    if $isdir {
 	if {$entry != "/"} {
 	    set entry [string trimright $entry /]
 	}
@@ -811,6 +825,10 @@ proc dsk_filesel_browse {entry val} {
 			-filter $entry/[file tail $dsk_filesel(filter)] \
 			-label $dsk_filesel(label) -showall $showall]
 	    } else {
+		global tk_strictMotif
+
+		#set osm $tk_strictMotif
+		#set tk_strictMotif 0
 		if $dsk_filesel(saving) {
 		    set file [tk_getSaveFile -title $dsk_filesel(label) \
 			    -initialdir $entry]
@@ -818,6 +836,7 @@ proc dsk_filesel_browse {entry val} {
 		    set file [tk_getOpenFile -title $dsk_filesel(label) \
 			    -initialdir $entry]
 		}
+		#set tk_strictMotif $osm
 	    }
 	}
     } else {
@@ -825,16 +844,21 @@ proc dsk_filesel_browse {entry val} {
 	    set tkdesk(_ed_browser) [dsk_open_dir [file dirname $entry]]
 	} else {
 	    if {[info command tk_getSaveFile] == {}} {
-		set file [cb_fileSelector -filter $dsk_filesel(filter) \
+		set file [cb_fileSelector -filter $dir/$dsk_filesel(filter) \
 			-label $dsk_filesel(label) -showall $showall]
 	    } else {
+		global tk_strictMotif
+
+		#set osm $tk_strictMotif
+		#set tk_strictMotif 0
 		if $dsk_filesel(saving) {
 		    set file [tk_getSaveFile -title $dsk_filesel(label) \
-			    -initialdir $entry]
+			    -initialdir $dir]
 		} else {
 		    set file [tk_getOpenFile -title $dsk_filesel(label) \
-			    -initialdir $entry]
+			    -initialdir $dir]
 		}
+		#set tk_strictMotif $osm
 	    }
 	}
     }
@@ -860,6 +884,8 @@ proc dsk_cd {{dir ""} {openNew 0}} {
 
     if {$dir == ""} return
     if {$dir == "\{\}"} {dsk_errbell; return}
+
+    set special ""
     
     if $tkdesk(menu,control) {
 	set openNew 1
@@ -874,7 +900,10 @@ proc dsk_cd {{dir ""} {openNew 0}} {
 	}
 	set dir [file dirname [string trimright $ad /]]
     } elseif ![file isdirectory $dir] {
-	if !$openNew {
+	if [regexp {\.tar\.gz$|\.tgz$} $dir] {
+	    # it's a compressed tar file
+	    set special "tar"
+	} elseif !$openNew {
 	    set dir [file dirname $dir]
 	} else {
 	    dsk_open {} $dir
@@ -883,11 +912,14 @@ proc dsk_cd {{dir ""} {openNew 0}} {
     }
 
     if {$dir != "" && [winfo exists $tkdesk(active_viewer)]} {
-	if ![file isdirectory $dir] {
+	if {![file isdirectory $dir] && $special == ""} {
 	    set dir [_make_path_valid $dir]
 	    catch {dsk_bell}
 	    cb_alert "The path you specified does not exist."
 	}
+	if {[info command dsk_cd_callback] != ""} {
+	    dsk_cd_callback $dir
+	}
 	if !$openNew {
 	    $tkdesk(active_viewer) config -directory $dir
 	} else {
@@ -1169,9 +1201,17 @@ proc dsk_edit {args} {
     global tkdesk
 
     set files ""
+    set linenum ""
     foreach f $args {
-	if ![file isdirectory $f] {
-	    lappend files $f
+	if [regexp {^\+[1-90]+$} $f] {
+	    set linenum $f
+	} elseif ![file isdirectory $f] {
+	    if {$linenum != ""} {
+		lappend files [list $linenum $f]
+		set linenum ""
+	    } else {
+		lappend files $f
+	    }
 	}
     }
 
@@ -1188,9 +1228,11 @@ proc dsk_edit {args} {
 	while {1} {
 	    set files [dsk_filesel "File to edit:" \
 		    [string trimright [dsk_active dir] /]/* showall]
+	    set isdir 0
+	    catch {set isdir [file isdirectory $files]}
 	    if {$files == ""} {
 		return
-	    } elseif [file isdirectory $files] {
+	    } elseif $isdir {
 		dsk_errbell
 		cb_error "$files is a directory. Please choose a file."
 	    } else {
@@ -1204,7 +1246,8 @@ proc dsk_edit {args} {
 	    eval dsk_exec $tkdesk(editor,cmd) $files
 	} else {
 	    if {$files != ""} {
-		dsk_Editor .de[dsk_Editor :: id] -files $files
+		dsk_Editor [set e .de[dsk_Editor :: id]] -files $files
+		if {[string length [$e cget -files]] == 0} {$e delete}
 		#dsk_editor load $files
 	    } else {
 		dsk_editor new
@@ -1215,10 +1258,10 @@ proc dsk_edit {args} {
 	    if {$tkdesk(editor,cmd) != "builtin"} {
 		dsk_exec $tkdesk(editor,cmd) $file
 	    } else {
-		dsk_Editor .de[dsk_Editor :: id] -files $file
+		dsk_Editor [set e .de[dsk_Editor :: id]] -files $file
+		if {[string length [$e cget -files]] == 0} {$e delete}
 		#dsk_editor load $file
 	    }
-
 	}
     }
 
@@ -1247,18 +1290,6 @@ proc dsk_view {args} {
     eval dsk_editor cmd $args
 }
 
-# ----------------------------------------------------------------------------
-# dsk_man name ?section?:
-# Displays a man page in TkDesk's help browser.
-
-proc dsk_man {name {section ""}} {
-    global dsk_editor
-
-    set cmd "|man $section $name | col -b"
-
-    cb_help show $cmd man
-}
-
 #
 # -----------------------------------------------------------------------------
 #
@@ -1277,6 +1308,19 @@ proc dsk_confirm {msg script} {
     }
 }
 
+proc dsk_msg_alert {msg} {
+    cb_alert $msg
+}
+
+proc dsk_msg_info {msg} {
+    cb_alert $msg
+}
+
+proc dsk_msg_error {msg} {
+    cb_alert $msg
+}
+
+
 #
 # -----------------------------------------------------------------------------
 #
@@ -1309,12 +1353,18 @@ proc dsk_read_string {msg {script {}} args} {
     }
     set dsk_read_string_script $script
     set dsk_read_string {}
+    if {[string length $script] == 0} {
+	set noapply 1
+    } else {
+	set noapply 0
+    }
 
     dsk_HistEntry .he[dsk_HistEntry :: id] \
 	    -title "Enter String" \
 	    -label $msg \
 	    -entrydefault $tmpvar \
 	    -history string_history \
+	    -noapply $noapply \
 	    -callback dsk_read_string_ok
 
     return $dsk_read_string
@@ -1373,7 +1423,13 @@ proc dsk_cbhelp {file {regexp ""}} {
     global tkdesk
 
     dsk_busy
+    if {[string first "|" $file] > -1} {
+	dsk_status "Launched:  [string trimleft $file {| }]"
+    }
     cb_help show $file $regexp
+    if {[string first "|" $file] > -1} {
+	dsk_status "Exit:  [string trimleft $file {| }]"
+    }
     dsk_lazy
 }
 
@@ -1686,8 +1742,10 @@ proc dsk_man {{names ""}} {
 	set l [split $name ()]
 	if {[llength $l] == 1} {
 	    dsk_view man $l | col -b
+	    #dsk_cbhelp "| man $l | col -b" man
 	} else {
 	    dsk_view man [lindex $l 1] [lindex $l 0] | col -b
+	    #dsk_cbhelp "| man [lindex $l 1] [lindex $l 0] | col -b" man
 	}
     }
 }
