@@ -79,7 +79,7 @@ proc dsk_appbar {args} {
 	set opts [lrange $args 1 [llength $args]]
 	switch $cmd {
 	    layout	{eval _appbar_layout $opts}
-	    move	{eval _appbar_move}
+	    move	{eval _appbar_move $opts}
 	    raise	{eval _appbar_raise}
 	    lower	{eval _appbar_lower}
 	    close	{eval _appbar_close}
@@ -123,7 +123,7 @@ proc _appbar_create {} {
     dsk_busy 
 
     toplevel $t
-    #wm withdraw $t
+    wm withdraw $t
 
     set side top
     set fside left
@@ -141,7 +141,7 @@ proc _appbar_create {} {
     # Setup Quick Menus
     menu [set m .dsk_appbar.qmConfig]
     foreach cf $tkdesk(configfiles) {
-	$m add command -label $cf \
+	$m add command -label "$cf" \
 		-command "dsk_edit_configs $cf"
     }
     menu [set m .dsk_appbar.qmAppbar]
@@ -153,6 +153,13 @@ proc _appbar_create {} {
     $m add command -label {Raise} -command {dsk_appbar raise}
     $m add command -label {Lower} -command {dsk_appbar lower}
     $m add command -label {Hide} -command {dsk_appbar close}
+    $m add separator
+    $m add command -label {Move Top Left} -command {dsk_appbar move topleft}
+    $m add command -label {Move Bottom Left} \
+	    -command {dsk_appbar move bottomleft}
+    $m add command -label {Move Top Right} -command {dsk_appbar move topright}
+    $m add command -label {Move Bottom Right} \
+	    -command {dsk_appbar move bottomright}
 
     if {[llength [array names tkdesk appbar-*]] > 0} {
 	# There's more than one AppBar defined -> create menu
@@ -162,6 +169,29 @@ proc _appbar_create {} {
 	menu $m
 	pack $t.mbBarSel -fill x
     }
+
+    #
+    # Create Drag/Toggle Area
+    #
+    button $t.bDrag -bitmap gray12 \
+	    -height 8 -width 8 -cursor top_left_arrow \
+	    -padx 0 -pady 0 -highlightthickness 0 \
+	    -command _appbar_toggle_vis
+    if {$dsk_appbar(layout) == "vertical"} {
+	pack $t.bDrag -padx 0 -pady 0 -fill x -side $side
+    } else {
+	pack $t.bDrag -padx 0 -pady 0 -fill y -side $side
+    }
+    set cc white
+    if {[winfo depth .] != 1} {
+	set cc [cb_col $tkdesk(color,drag)]
+    }
+    bindtags $t.bDrag "appbar $t.bDrag Button all"
+    bind $t.bDrag <ButtonPress-1> {
+	set dsk_appbar(oldx) [winfo rootx .dsk_appbar]
+	_appbar_bind_global_b1 %W %X %Y
+	#break
+    }
     
     set count 0
     set fcount 0
@@ -326,6 +356,8 @@ proc _appbar_create {} {
 
 	incr count
     }
+    set dsk_appbar(fcount) $fcount
+    set dsk_appbar(is_visible) 1
 
     bind $t <Enter> {_appbar_auto_raise}
 
@@ -333,8 +365,10 @@ proc _appbar_create {} {
     if {$tkdesk(geometry,dsk_appbar) == ""} {
 	wm geometry $t +0+0
     } else {
-	set glist [split $tkdesk(geometry,dsk_appbar) x+]
-	wm geometry $t +[lindex $glist 2]+[lindex $glist 3]
+	set pi [string first "+" $tkdesk(geometry,dsk_appbar)]
+	set pi2 [string first "-" $tkdesk(geometry,dsk_appbar)]
+	if {$pi2 > -1 && ($pi2 < $pi || $pi < 0)} {set pi $pi2}
+	wm geometry $t [string range $tkdesk(geometry,dsk_appbar) $pi 1000]
     }
 
     if $tkdesk(appbar,wm_managed) {
@@ -349,6 +383,40 @@ proc _appbar_create {} {
     dsk_lazy
 }
 
+proc _appbar_toggle_vis {} {
+    global dsk_appbar
+
+    if [info exists dsk_appbar(oldx)] {
+    	  if {$dsk_appbar(oldx) != [winfo rootx .dsk_appbar]} {
+    	      return
+    	  }
+    }
+
+    set t .dsk_appbar
+    if $dsk_appbar(is_visible) {
+	if {$dsk_appbar(layout) == "vertical"} {
+	    $t.bDrag config -width [expr [winfo reqwidth $t] -4]
+	} else {
+	    $t.bDrag config -height [expr [winfo reqheight $t] -4]
+	}
+	for {set i 1} {$i <= $dsk_appbar(fcount)} {incr i} {
+	    pack forget $t.f$i
+	}
+	set dsk_appbar(is_visible) 0
+    } else {
+	if {$dsk_appbar(layout) == "vertical"} {
+	    set fside left
+	} else {
+	    set fside top
+	}
+	for {set i 1} {$i <= $dsk_appbar(fcount)} {incr i} {
+	    pack $t.f$i -side $fside -fill both
+	}
+	$t.bDrag config -width 8 -height 8
+	set dsk_appbar(is_visible) 1
+    }
+}
+
 proc _appbar_mcheck {appmenu nr menu} {
     if {[$appmenu index active] != $nr && \
 	[string first "tearoff" $menu] == -1} {
@@ -368,6 +436,8 @@ proc _appbar_handle_special_entry {m me} {
 	    
     if {$me == "-"} {
 	$m add separator
+    } elseif {$me == "."} {
+	$m config -tearoff 1
     } elseif {$me == "history:dirs"} {
 	$m add cascade -label "Directories" -menu $m.mhd
 	menu $m.mhd -postcommand \
@@ -439,14 +509,23 @@ proc _appbar_handle_special_entry {m me} {
 	#	 -menu $m.cfg.rdmenu
 	#
 	#menu [set tm $m.cfg.edmenu]
-	$tm add command -label "All" \
-		-command "dsk_edit_configs"
-	$tm add separator
 	foreach cf $tkdesk(configfiles) {
-	    $tm add command -label $cf \
+	    set cfs [format "%-12s" $cf]
+	    $tm add command -label "$cfs 	($tkdesk(configxpl,$cf))" \
 		    -command "dsk_edit_configs $cf"
 	}
-
+	$tm add command -label "Find..." \
+		-command "dsk_find_files -path $tkdesk(configdir) -name [list $tkdesk(configfiles)] -type file"
+	$tm add separator
+	$tm add command -label "Colors..." \
+			-command "dsk_config_panel colors"
+	$tm add command -label "Fonts..." \
+			-command "dsk_config_panel fonts"
+	$tm add command -label "Icons..." \
+			-command "dsk_config_panel icons"
+	$tm add command -label "Sounds..." \
+			-command "dsk_config_panel sounds"
+	
 	#menu [set tm $m.cfg.rdmenu]
 	#$tm add command -label "All" \
 	#	 -command "dsk_reread_config"
@@ -607,9 +686,11 @@ proc _appbar_motion {lastnum x y {win ""}} {
     
     if {$new != $dsk_appbar(lastbut)} {
 	if {[string match $t.b* $new] && [winfo class $new] == "Button"} {
-	    $t.m$lastnum unpost
 	    scan $new "$t.b%d" num
-	    _appbar_show_menu $num $x $y
+	    if [info exists num] {
+		$t.m$lastnum unpost
+		_appbar_show_menu $num $x $y
+	    }
 	} else {
 	    catch {set num $dsk_appbar(num,$new)}
 	    if [info exists num] {
@@ -703,18 +784,24 @@ proc _appbar_lower {} {
 #
 
 proc _appbar_layout {orient} {
-    global dsk_appbar
+    global dsk_appbar tkdesk
 
     if ![winfo exists .dsk_appbar] return
 
+    if !$dsk_appbar(is_visible) {
+	_appbar_toggle_vis
+    }
+
     if {$orient == "horizontal"} {
 	set side left
 	set fside top
 	set dsk_appbar(layout) horizontal
+	pack config .dsk_appbar.bDrag -padx 0 -pady 0 -fill y -side $side
     } else {
 	set side top
 	set fside left
 	set dsk_appbar(layout) vertical
+	pack config .dsk_appbar.bDrag -padx 0 -pady 0 -fill x -side $side
     }
 
     foreach obj [winfo children .dsk_appbar] {
@@ -747,14 +834,32 @@ proc _appbar_layout {orient} {
 # Side-FX:	none
 #
 
-proc _appbar_move {} {
+proc _appbar_move {{where ""}} {
     global dsk_appbar tkdesk cb_tools
 
-	if {[winfo depth .] != 1} {
-	    set cc [cb_col $tkdesk(color,drag)]
-	} else {
-	    set cc white
+    if {$where != ""} {
+	switch $where {
+	    topleft {
+		wm geometry .dsk_appbar +0+0
+	    }
+	    bottomleft {
+		wm geometry .dsk_appbar +0-0
+	    }
+	    topright {
+		wm geometry .dsk_appbar -0+0
+	    }
+	    bottomright {
+		wm geometry .dsk_appbar -0-0
+	    }
 	}
+	return
+    }
+
+    if {[winfo depth .] != 1} {
+	set cc [cb_col $tkdesk(color,drag)]
+    } else {
+	set cc white
+    }
 
     catch "unset dsk_appbar(released)"
 	catch {destroy .dsk_appbar._Busy}
@@ -830,16 +935,7 @@ proc _appbar_bind_special {widgets count mw} {
 proc _appbar_bind_global {} {
 
     bind appbar <Alt-Button-1> {
-	set dsk_appbar(tmp_bh) $cb_tools(balloon_help)
-	set cb_tools(balloon_help) 0
-	# doesn't help:
-	#destroy .cb_balloon; update
-	set dsk_appbar(mx) [expr %X - [winfo rootx .dsk_appbar]]
-	set dsk_appbar(my) [expr %Y - [winfo rooty .dsk_appbar]]
-	%W config -cursor "@$tkdesk(library)/images/xbm/hand.xbm \
-		$tkdesk(library)/images/xbm/hand.mask.xbm \
-		[cb_col $tkdesk(color,foreground)] $tkdesk(color,drag)"
-	raise .dsk_appbar
+	_appbar_bind_global_b1 %W %X %Y
 	break
     }
     bind appbar <Meta-Button-1> [bind appbar <Alt-Button-1>]
@@ -860,7 +956,7 @@ proc _appbar_bind_global {} {
 	    unset dsk_appbar(my)
 	    set cb_tools(balloon_help) $dsk_appbar(tmp_bh)
 	    %W config -cursor top_left_arrow
-	    break
+	    #break
 	}
     }
 
@@ -904,6 +1000,20 @@ proc _appbar_bind_global {} {
     }
 }
 
+proc _appbar_bind_global_b1 {W X Y} {
+    global dsk_appbar cb_tools tkdesk
+    
+    set dsk_appbar(tmp_bh) $cb_tools(balloon_help)
+    set cb_tools(balloon_help) 0
+    set dsk_appbar(mx) [expr $X - [winfo rootx .dsk_appbar]]
+    set dsk_appbar(my) [expr $Y - [winfo rooty .dsk_appbar]]
+    $W config -cursor "@$tkdesk(library)/images/xbm/hand.xbm \
+	    $tkdesk(library)/images/xbm/hand.mask.xbm \
+	    [cb_col $tkdesk(color,foreground)] $tkdesk(color,drag)"
+    raise .dsk_appbar
+}
+
+
 # -----------------------------------------------------------------------------
 # _appbar_get_button_width:
 # Returns the width of the first button in the appbar - 4. This should
@@ -923,3 +1033,21 @@ proc _appbar_get_button_width {} {
     return $w
 }
 
+# -----------------------------------------------------------------------------
+# dsk_appbar_adjgeom geom:
+# Swaps width and height info in $geom if appbar is currently minimized.
+# (Called from config.tcl:save__layout)
+#
+proc dsk_appbar_adjgeom {geom} {
+    global dsk_appbar
+
+    if !$dsk_appbar(is_visible) {
+	set gl [split $geom "x+-"]
+	set pi [string first "+" $geom]
+	set pi2 [string first "-" $geom]
+	if {$pi2 > -1 && ($pi2 < $pi || $pi < 0)} {set pi $pi2}
+	set geom [lindex $gl 1]x[lindex $gl 0][string range $geom $pi 1000]
+	dsk_debug "geom: $geom"
+    }
+    return $geom
+}
