@@ -22,7 +22,7 @@ set cb_tools(keys_bound) 1
 # Make some bindings available even if tk_strictMotif is true:
 #if $tk_strictMotif {}
 # Buttons:
-bind Button <Return> [bind Button <space>]
+bind Button <Return> "[bind Button <space>]; break"
 bind Checkbutton <Return> [bind Button <space>]
 bind Radiobutton <Return> [bind Button <space>]
 bind Entry <Control-d> {%W delete insert}
@@ -476,14 +476,20 @@ proc cb_Text_change_callback {w {type unknown} {data x}} {
 proc cb_addShortcutBinding {widget button char args} {
 
     set char [string tolower $char]
-    bind $widget <Alt-$char> \
-	    "$button config -relief sunken ;\
-	    update idletasks ;\
-	    after 100 ;\
-	    $button config -relief raised ;\
-	    update idletasks ;\
-	    $button invoke ;\
-	    break"
+    if {[winfo class $button] == "Button"} {
+	bind $widget <Alt-$char> \
+		"$button config -relief sunken ;\
+		update idletasks ;\
+		after 100 ;\
+		$button config -relief raised ;\
+		update idletasks ;\
+		$button invoke ;\
+		break"
+    } else {
+	bind $widget <Alt-$char> \
+		"$button invoke ;\
+		break"
+    }
     bind $widget <Meta-$char> [bind $widget <Alt-$char>]
     bind $widget <Control-$char> [bind $widget <Alt-$char>]
 }
