@@ -219,8 +219,16 @@ proc cb_tilde {path {mode "normal"}} {
 	return $rpath
     } elseif {$mode != "expand"} {
 	set hp [string first $env(HOME) $path]
-	if {$hp == 0} {
-	    set path ~[string range $path [string length $env(HOME)] end]
+	if {$hp == 0 && ![string match $env(HOME) "/"]} {
+	    # check whether HOME's like "/home/user/" as opposed to
+	    # "/home/user"
+	    if {[string index $env(HOME) \
+		    [expr [string length $env(HOME)] -1 ]] \
+		    == "/"} {
+		set path ~/[string range $path [string length $env(HOME)] end]
+	    } else {
+		set path ~[string range $path [string length $env(HOME)] end]
+	    }
 	}
 	return $path
     } else {
@@ -766,3 +774,32 @@ proc cb_deiconify {window} {
 	}
     }
 }
+
+# ---------------------------------------------------------------------------
+# cb_random limit ?seed?:
+# Copied from the Tcl FAQ, this proc returns and int bw. 0 and limit-1.
+# Seed value may be given as 2nd param, such as: [pid], [dev/kmem].
+#
+proc cb_random {args} {
+    global RNG_seed
+    
+    set max 259200
+    set argcnt [llength $args]
+    if { $argcnt < 1 || $argcnt > 2 } {
+	error "wrong # args: random limit | seed ?seedval?"
+    }
+    if ![string compare [lindex $args 0] seed] {
+	if { $argcnt == 2 } {
+	    set RNG_seed [lindex $args 1]
+	} else {
+	    set RNG_seed [expr \
+                    ([pid]+[file atime /dev/kmem])%$max]
+	}
+	return
+    }
+    if ![info exists RNG_seed] {
+	set RNG_seed [expr ([pid]+[file atime /dev/kmem])%$max]
+    }
+    set RNG_seed [expr ($RNG_seed*7141+54773) % $max]
+    return [expr int(double($RNG_seed)*[lindex $args 0]/$max)]
+}
\ No newline at end of file
