@@ -197,3 +197,9 @@ Tcl_AppInit(interp)
     /*tcl_RcFileName = "~/.tkdeskrc";*/
     return TCL_OK;
 }
+
+#ifdef STATIC_BUILD
+void dlopen() {};
+void dlsym() {};
+void dlerror() {};
+#endif
